/**
 * SantaPress Public JavaScript
 *
 * @link       https://santapress.halloecho.de
 * @since      1.0.0
 *
 */
(function( $ ) {
	'use strict';
	
	// Open modal in AJAX callback
	$(function() {

		// put bootstrap modal in noConflict() mode (only bootstrap modal supports the noConflict() method)
		if ( $.isFunction($.fn.modal.noConflict) ) {
			var bsModal = $.fn.modal.noConflict();
		}

		$( document ).on( 'click', '.santapress-modal', function() {
			event.preventDefault();
			this.blur(); // Manually remove focus from clicked link.
			$.ajax({
				url: this.href,
				data: {},
				success: function (result) {
					var $el = $(result).find(".santapress-post");
					$el.hide();
					$el.appendTo('body').modal({
						fadeDuration: 200
					});
					// WPCF7 integration
					if($el.html().indexOf('wpcf7') !== -1)
						wpcf7.initForm( $('.wpcf7-form') );
					// add modal open class to body (e.g. for snow delay)
					setTimeout(function(){
						$('body').addClass('modal-open');
					}, 350);
				},
				dataType: 'html'
			});
			$(this).addClass('open');
		});
		$('.santapress-modal').each(function() {
			$(this).addClass('loaded');
		});
		$(document).on($.modal.CLOSE, function() {
			$('.santapress-modal').removeClass('open');
			$('body').removeClass('modal-open');
		});

		if( $('.santapress-container').hasClass('tr') ) {
			$( document ).on( 'click', '.santapress-door.status-publish', function() {
				var post_id = $(this).data('postid');
				$.post( data.plugin_public_dir_url + 'ajax/track.php', { post_id: post_id } );
			});
		}

		// Append Snow
		if( $('.santapress-container').hasClass('with-snow') ) {
			// Get snowcond and snowtype
			var snowcond = $('.santapress-container').data('snowcond');
			var snowtype = $('.santapress-container').data('snowtype');
			if(snowtype == 'santapress') {
				if(snowcond == 'modal') {
					$('body').addClass('santapress-snow-modal');
				}
				if(snowcond == 'everywhere') {
					$('<div class="spsnow"></div>').appendTo('body'); // appent snow container to body
					$('body').addClass('santapress-snow-everywhere');
					if( !$('.santapress-container').hasClass('hiddenmode') ) {
						setTimeout(function(){
							$('body').addClass('santapress-snow-everywhere-active');
						}, 400);
					}
				}
			}
		}

		// Hidden mode
		if( $('.santapress-container').hasClass('hiddenmode') ) {
			$('.santapress-container').appendTo('body').removeClass('hiddenmode').wrap('<div class="santapress-container-outer"></div>');
			var timeout = $('.santapress-container').data('timeout');
			var hideafterclose = $('.santapress-container').data('hideafterclose');
			var hideCalender = false;
			if( (hideafterclose == 'session' || hideafterclose == 'midnight' || typeof hideafterclose === 'number') && sp_getcookie('sp_hm_exp') )
				hideCalender = true;
			// fadeIn calendar and reinforce cookie to be set if shortcode variable was changed
			if ((hideafterclose == 'session' && sp_getcookie('sp_hm_exp') !== 'session') ||
				(hideafterclose == 'midnight' && sp_getcookie('sp_hm_exp') !== 'midnight') ||
				(typeof hideafterclose === 'number' && sp_getcookie('sp_hm_exp') !== 'h') ) {
				hideCalender = false;
			}
			if(!hideCalender) {
				// fadeIn calendar
				if(timeout > 0) {
					setTimeout(function(){
						$('.santapress-container-outer').fadeIn().addClass('active');
						$('body').addClass('santapress-snow-everywhere-active');
						// if variable 'hide_after_close' is set in shortcode set expiration cookies
						if(hideafterclose) {
							if(hideafterclose == 'session')
								document.cookie = encodeURIComponent('sp_hm_exp') + "=" + encodeURIComponent( 'session' ) + "; path=/";
							else if(hideafterclose == 'midnight') {
								var d = new Date(); // create new date object for cookie expiration
								d.setHours(24,0,0,0); // set date to next midnight
								var expires = "; expires=" + d.toGMTString();
								document.cookie = encodeURIComponent('sp_hm_exp') + "=" + encodeURIComponent( 'midnight' ) +  expires + "; path=/";
							}
							else if( typeof hideafterclose === 'number' && hideafterclose % 1 === 0 ) { // check if variable is an integer
								var d = new Date(); // create new date object for cookie expiration
								d.setTime(d.getTime() + (hideafterclose*60*60*1000));
								var expires = "; expires=" + d.toGMTString();
								document.cookie = encodeURIComponent('sp_hm_exp') + "=" + encodeURIComponent( 'h' ) +  expires + "; path=/";
							}
							else {
								console.log('SantaPress: Something is wrong with the variable "hide_after_close" you have provided in the shortcode: ' + hideafterclose);
							}
						}
					}, timeout);
				}
			}
			// Trigger
			var triggerClass = $('.santapress-container').data('trigger');
			$( document ).on( 'click', triggerClass, function() {
				$('.santapress-container-outer').fadeIn().addClass('active');
				$('body').addClass('santapress-snow-everywhere-active');
			});
			// Prepend buildin trigger container
			if($('#santapress-trigger').length) {
				$('#santapress-trigger').prependTo('body');
			}
		}
		$( document ).on( 'click', '#sp-close-hidden-mode', function() {
			$('.santapress-container-outer').removeClass('active').fadeOut();
			$('body').removeClass('santapress-snow-everywhere-active');
		});

		// Quiz
		$( document ).on( 'click', '.spquiz-answer', function(event) {
			event.preventDefault();
			this.blur(); // Manually remove focus from clicked link.
			var $loader = $(this).find('.spquiz-loader');
			var $answers_wrapper = $(this).parent();
			var $quiz_wrapper = $(this).parent().parent();
			var $result_wrapper = $(this).parent().parent().find('.spquiz-result');
			$loader.show();
			$.ajax({
				url: data.plugin_public_dir_url + 'ajax/quiz-answer.php',
				type: "POST",
				data: { post_id: $(this).parent().parent().data('postid'), answer: encodeURIComponent($(this).text()) },
				success: function (result) {
					$loader.hide();
					$answers_wrapper.hide();
					$result_wrapper.html(result).fadeIn();
					// check if a wpcf7 form was returned and initialize if needed
					if(result.indexOf('wpcf7') !== -1) {
						wpcf7.initForm( $('.wpcf7-form') );
					}
					// set quiz cookie if needed
					if( $quiz_wrapper.data('qc') == 1 ) {
						var d = new Date(); // create new date object for cookie expiration
						d.setHours(24,0,0,0); // set date to next midnight
						var expires = "; expires=" + d.toGMTString();
						var postid = $quiz_wrapper.data('postid');
						if($quiz_wrapper.data('qctype') == 1) { // set cookie after an answer 
							setTimeout(function(){
								document.cookie = encodeURIComponent('sp_quiz_cookie') + "=" + encodeURIComponent( postid ) + expires + "; path=/";
							}, 500);
						}
						else { // set cookie after the contact form was submitted
							document.addEventListener( 'wpcf7mailsent', function( event ) { // set event listener when the contact form was sent
								setTimeout(function(){
									document.cookie = encodeURIComponent('sp_quiz_cookie') + "=" + encodeURIComponent( postid ) + expires + "; path=/";
								}, 500);
							}, false );
						}
					}
				}
			});
		});

		$( document ).on( 'click', '.spquiz-back', function(event) {
			event.preventDefault();
			this.blur(); // Manually remove focus from clicked link.
			$(this).parent().parent().parent().find('.spquiz-answers').show();
			$(this).parent().parent().html(''); // clears .spquiz-result div
			
		});

		// helper function to get cookies
		function sp_getcookie(name) {
		    var v = document.cookie.match('(^|;) ?' + name + '=([^;]*)(;|$)');
		    return v ? v[2] : null;
		}

	});

})( jQuery );
